class BMI:
	def __init__(self, age, weight, height, gender):
		self.age = age
		self.weight = weight
		self.height = height
		self. gender = gender
		self.bmi = 0

	def bmi(self):
		if self.gender.upper() == 'male'.upper():
			self.bmi = self.weight / ((self.height/100)**2) * 0.98
		else:
			self.bmi = self.weight / ((self.height/100)**2) * 0.94
		return self.bmi

	def conclusion(self):
		if self.bmi < 18.5:
			return 'underweight'
		elif self.bmi < 24.9:
			return 'normal'
		elif self.bmi < 29.9:
			return 'overweight'




class Person(object):
	def __init__(self, name, idnumber):
		self.name = name
		self.idnumber = idnumber

	def display(self):
		print(self.name)
		print(self.idnumber)
		
	def details(self):
		print("My name is {}".format(self.name))
		print("IdNumber: {}".format(self.idnumber))
	
class Employee(Person):
	def __init__(self, name, idnumber, salary, post):
		self.salary = salary
		self.post = post

		# invoking the __init__ of the parent class
		Person.__init__(self, name, idnumber)
		
	def details(self):
		print("My name is {}".format(self.name))
		print("IdNumber: {}".format(self.idnumber))
		print("Post: {}".format(self.post))
